%global commit dcc17cdee75c55ab9d355d63b428db04c66b999b
%global gittag 1.0.3
%global shortcommit %(c=%{commit}; echo ${c:0:7})
# Upstream requests use of -O3 for DSP performance and specifies c++17
%global optflags %(eval echo %{optflags} | %{__sed} -e 's/-O2/-O3 -std=c++17/')

Name:           sdrpp
Version:        1.0.3
Release:        2%{?dist}
Summary:        SDRPlusPlus bloat-free SDR receiver software

License:        GPLv3 and MIT and WTFPL and Public Domain
URL:            https://github.com/AlexandreRouma/SDRPlusPlus/
Source0:        https://github.com/AlexandreRouma/SDRPlusPlus/archive/%{commit}/%{name}-%{shortcommit}.tar.gz
# Note: the changes which these patches perform are discussed in upstream issue
# https://github.com/AlexandreRouma/SDRPlusPlus/issues/292
# Becuase upstream intends to rework their whole cmake build system
# as noted in this issue, I merely provided suggestions as to what to change
# rather than specific patches which aren't likely exactly what upstream will
# do.
#
# Override upstream definitions of CMAKE_CXX_FLAGS throughout in favor of
# rpmbuild-provided flags. Prevent discord-rpc from building as a shared
# library
Patch0:         cmake-flags.patch
# Install plugins to _libdir
Patch1:         plugins-libdir.patch
# Ensure generated config.json modulesDirectory uses _libdir
Patch2:         configfile-libdir.patch
# Remove rapidjson in favor of system library
Patch3:         remove-rapidjson.patch
# Changes to top-level and core CMakeLists.txt to complete the above changes.
# Set soname on libsdrpp_core.so
# Install libsdrpp_core.so in _libdir
Patch4:         cmake-top.patch

BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  fftw-devel glew-devel volk-devel glfw-devel
BuildRequires:  portaudio-devel libiio-devel rtaudio-devel
BuildRequires:  spdlog-devel fmt-devel rapidjson-devel json-devel
BuildRequires:  stb_image-devel stb_image_resize-devel
BuildRequires:  stb_truetype-devel
BuildRequires:  SoapySDR-devel hackrf-devel rtl-sdr-devel
BuildRequires:  desktop-file-utils
Requires: google-roboto-fonts

# Bundled libraries
# https://github.com/AlexandreRouma/SDRPlusPlus/issues/292
# https://github.com/ocornut/imgui
# MIT License
Provides: bundled(imgui) = 1.83
# imgui itself bundles stb_rect_pack and stb_textedit with changes that do not
# match upstream stb so we can't remove it in favor of library code. It is essentially
# a private fork of upstream stb.  stb_truetype matches upstream now, so that was unbundled.
#
# https://github.com/samhocevar/portable-file-dialogs
# WTFPL License
Provides: bundled(portable-file-dialogs) = 0.1.0
#
# https://github.com/discord/discord-rpc
# MIT License
# Note: this library is deprecated by upstream in favor of Discord's GameSDK. Therefore
# this should not be packaged into Fedora separately.
Provides: bundled(discord-rpc) = 3.4.0
# A local copy of libsddc is present in sddc_source but is not built.
# A local copy of libcorrect is present in falcon9_decoder but is not built.
# A local copy of nlohmann-json is present in the source and is deleted prior to building.
# A local copy of stb_image and stb_image_resize is present in the source and is deleted prior to building.
# A local copy of rapidjson is present in the source and is deleted prior to building.
# A local copy of spdlog is present in the source and is deleted prior to building.


%description
SDR++ is a cross-platform and open source SDR software
with the aim of being bloat free and simple to use.

Features
- Wide hardware support (both through SoapySDR and dedicated modules)
- SIMD accelerated DSP
- Full waterfall update when possible. Makes browsing signals
  easier and more pleasant

%prep
%autosetup -p1 -n SDRPlusPlus-%{commit}
# Delete local copy of spdlog. We're using the system library copy.
rm -rf core/src/spdlog
# Delete local copy of rapidjson. We're using the system library copy.
rm -rf discord_integration/discord-rpc/include/rapidjson
# Replace use of local nlohmann-json with library version
rm core/src/json.hpp
grep -l -r '#include <json.hpp>' . | xargs sed -i -e 's:#include <json.hpp>:#include <nlohmann/json.hpp>:'
# Replace use of local stb_image and stb_image_resize with library version
rm core/src/imgui/stb_image_resize.h
rm core/src/imgui/stb_image.h
sed -i -e 's:#include <imgui/stb_image.h>:#include <stb/stb_image.h>:' core/src/gui/icons.cpp
sed -i -e 's:#include <stb_image.h>:#include <stb/stb_image.h>:' \
    -e 's:#include <stb_image_resize.h>:#include <stb/stb_image_resize.h>:' core/src/core.cpp
# replace use of local stb_truetype with library version
sed -i -e 's:#include "imstb_truetype.h":#include<stb/stb_truetype.h>:' core/src/imgui/imgui_draw.cpp


# Use system-provided roboto font
sed -i -e 's:resDir + "/fonts/Roboto-Medium.ttf":"%{_datadir}/fonts/google-roboto/Roboto-Medium.ttf":'   core/src/gui/style.cpp

%build

# Not building Falcon9 decoder as it requires ffplay which is in rpmfusion
# Not building hardware support which does not have libraries in Fedora
# Building for new PortAudio
%cmake -DOPT_BUILD_AIRSPY_SOURCE=OFF -DOPT_BUILD_AIRSPYHF_SOURCE=OFF \
       -DOPT_BUILD_BLADERF_SOURCE=OFF \
       -DOPT_BUILD_PLUTOSDR_SOURCE=OFF \
       -DOPT_BUILD_NEW_PORTAUDIO_SINK=ON

%cmake_build


%install
%cmake_install
rm %{buildroot}%{_libdir}/libsdrpp_core.so
rm -rf %{buildroot}%{_datadir}/%{name}/fonts


%check
# upstream has no tests for ctest except in unbuilt libsddc
desktop-file-validate %{buildroot}/%{_datadir}/applications/%{name}.desktop


%files
%license license discord_integration/discord-rpc/LICENSE
%doc readme.md contributing.md
%{_datadir}/%{name}
%{_libdir}/%{name}
%{_libdir}/lib%{name}_core.so.%{version}
%{_datadir}/applications/%{name}.desktop
%{_bindir}/%{name}



%changelog
* Sat Sep 18 2021 Matt Domsch <matt@domsch.com> - 1.0.3-2
- Package updates based on review feedback

* Sun Sep 12 2021 Matt Domsch <matt@domsch.com> - 1.0.3-1
- Initial package per Fedora Packaging Guidelines


